using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using MySql.Data;
using MySql.Data.MySqlClient;

public partial class Receive_server_transfer : System.Web.UI.Page
{
    protected void Page_Load(object sender, System.EventArgs e)
    {

        if (!Page.IsPostBack)
        {
            // This code runs when this page loads, the company ID is recevied from the session variable "CompanyID" and
            // the Asset type ID comes from the transfered Context.Items("AssetTypeID") by a Server.Transfer.
            // The Asset type is selected from the AssetType table based on the supplied AssetTypeID from HiddenAssetTypeID.

            // Retrieve a value from a session variable.
            HiddenCompanyID.Value = Convert.ToString(Session["CompanyID"]);

            // Retrieve a value from a item in a Server.Transfer.
            HiddenAssetTypeID.Value = Convert.ToString(Context.Items["AssetTypeID"]);

            if (!string.IsNullOrEmpty(HiddenAssetTypeID.Value))
            {

                string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
                string sql = "SELECT * FROM AssetType WHERE AssetTypeID = @AssetTypeID";

                // Create a MySqlConnection. The using block is used to call dispose (close) automatically 
                // even if there are an exception.
                using (MySqlConnection cn = new MySqlConnection(ConnString))
                {
                    // Create a MySqlCommand.
                    MySqlCommand cmd = new MySqlCommand(sql, cn);

                    // Create a MySqlDataReader
                    MySqlDataReader reader = null;

                    // Add parameters.
                    cmd.Parameters.AddWithValue("@AssetTypeID", HiddenAssetTypeID.Value);

                    try
                    {
                        // Open the connection.
                        cn.Open();

                        // Execute the SELECT statement.
                        reader = cmd.ExecuteReader(System.Data.CommandBehavior.SingleRow);

                        // A while loop.
                        while (reader.Read())
                        {
                            txtTillgangstypID.Text = reader["TypeOwnID"].ToString();
                            txtAssetTypeName.Text = reader["TypeName"].ToString();
                            NoDepricationCheckBox.Checked = Convert.ToBoolean(reader["NoDeprication"]);
                            txtAssetAccount.Text = reader["AssetAccount"].ToString();
                            txtAckDeprication.Text = reader["AccDepAccount"].ToString();
                            txtDepricationAccount.Text = reader["DepricationAccount"].ToString();
                            txtProfitSaleAccount.Text = reader["ProfitSaleAccount"].ToString();
                            txtLossSaleAccount.Text = reader["LossSaleAccount"].ToString();
                        }
                    }
                    catch (Exception ex)
                    {
                        // Catch a general exception.
                        Response.Write(ex.Message);
                    }
                    finally
                    {
                        // Dispose the MySqlCommand and close the MySqlDataReader.
                        cmd.Dispose();
                        
                        if (reader != null)
                            reader.Close();
                    }
                }
            }
            else
            {
                ErrorMessageLabel.Text = "* You have to choose an asset first";
            }
        }
    }

    protected void btnChangeAssetType_Click(object sender, System.EventArgs e)
    {
        
        // This code runs when a user has clicked the button to change asset type and updates the post in the
        // AssetType table with the changed data.


        if (!string.IsNullOrEmpty(HiddenAssetTypeID.Value))
        {

            // Declare variables for a connection string and a UPDATE statement.
            string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sql = "UPDATE AssetType SET TypeOwnID = @TypeOwnID, TypeName = @TypeName, NoDeprication = @NoDeprication, AssetAccount = @AssetAccount, AccDepAccount = @AccDepAccount, DepricationAccount = @DepricationAccount, ProfitSaleAccount = @ProfitSaleAccount, LossSaleAccount = @LossSaleAccount WHERE AssetTypeID = @AssetTypeID";

            // Create a MySqlConnection. The using block is used to call dispose (close) automatically even if 
            // there are an exception.
            using (MySqlConnection cn = new MySqlConnection(ConnString))
            {

                // Create a MySqlCommand.
                MySqlCommand cmd = new MySqlCommand(sql, cn);

                // Add parameters.
                cmd.Parameters.AddWithValue("@TypeOwnID", txtTillgangstypID.Text);
                cmd.Parameters.AddWithValue("@TypeName", txtAssetTypeName.Text);
                cmd.Parameters.AddWithValue("@NoDeprication", NoDepricationCheckBox.Checked);
                cmd.Parameters.AddWithValue("@AssetAccount", txtAssetAccount.Text);
                cmd.Parameters.AddWithValue("@AccDepAccount", txtAckDeprication.Text);
                cmd.Parameters.AddWithValue("@DepricationAccount", txtDepricationAccount.Text);
                cmd.Parameters.AddWithValue("@ProfitSaleAccount", txtProfitSaleAccount.Text);
                cmd.Parameters.AddWithValue("@LossSaleAccount", txtLossSaleAccount.Text);
                cmd.Parameters.AddWithValue("@AssetTypeID", HiddenAssetTypeID.Value);
                
                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Execute the UPDATE statement.
                    cmd.ExecuteNonQuery();

                    // Redirect the user to another web page.
                    Server.Transfer("List-assettypes.aspx");

                }
                catch (MySqlException ex)
                {
                    Response.Write(ex.Message);
                }
                catch (Exception ec)
                {
                    Response.Write(ec.Message);
                }
                finally
                {
                    // Dispose the MySqlCommand.
                    cmd.Dispose();
                }
            }
        }
        else
        {
            ErrorMessageLabel.Text = "* You have to choose an asset first";
        }
    }
}
